@@ -2,14 +2,14 @@ import logging
 
 from google.auth import default
 
-from cachetools import cached
 from dbnd._core.plugin.dbnd_plugins import use_airflow_connections
+from dbnd._core.utils.basics.memoized import per_thread_cached
 
 
 logger = logging.getLogger(__name__)
 
 
-@cached(cache={})
+@per_thread_cached()
 def get_gc_credentials():
     if use_airflow_connections():
         from dbnd_airflow_contrib.credentials_helper_gcp import GSCredentials
